======
Theory
======

These sections give an overview over theory that underlies the different aspects of
treams. For more in-depth information, there is also a list of associated
:ref:`about:Publications`.

.. toctree::
    :maxdepth: 1

    maxwell
